@@ -2,11 +2,21 @@
 # -*- coding: utf-8 -*-
 
 import unittest
-import time
-from datetime import datetime, date
+from datetime import datetime
 from croniter import croniter
 
 class CroniterTest(unittest.TestCase):
+  def testSecond(self):
+    base = datetime(2012, 4, 6, 13, 26, 10)
+    itr = croniter('*/1 * * * * *', base)
+    n1 = itr.get_next(datetime)    
+    self.assertEqual(base.year,   n1.year)
+    self.assertEqual(base.month,  n1.month)
+    self.assertEqual(base.day,    n1.day)
+    self.assertEqual(base.hour,   n1.hour)
+    self.assertEqual(base.minute, n1.minute)
+    self.assertEqual(base.second + 1, n1.second)    
+  
   def testMinute(self):
     # minute asterisk
     base = datetime(2010, 1, 23, 12, 18)
@@ -120,7 +130,6 @@ class CroniterTest(unittest.TestCase):
     self.assertEqual(n4.year, 2011)
 
   def testError(self):
-    base = datetime(2010, 1, 25)
     itr = croniter('* * * * *')
     self.assertRaises(TypeError, itr.get_next, str)
     self.assertRaises(ValueError, croniter, '* * * *')
@@ -155,6 +164,17 @@ class CroniterTest(unittest.TestCase):
     self.assertEqual(23, prev.hour)
     self.assertEqual(59, prev.minute)
 
+  def testPrevDayOfMonthWithCrossing(self):
+    """Test getting previous occurrence that crosses into previous month."""
+    base = datetime(2012, 3, 15, 0, 0)
+    itr = croniter('0 0 22 * *', base)
+    prev = itr.get_prev(datetime)
+    self.assertEqual(prev.year, 2012)
+    self.assertEqual(prev.month, 2)
+    self.assertEqual(prev.day, 22)
+    self.assertEqual(prev.hour, 0)
+    self.assertEqual(prev.minute, 0)
+
   def testPrevWeekDay(self):
     base = datetime(2010, 8, 25, 15, 56)
     itr = croniter('0 0 * * sat,sun', base)
@@ -179,7 +199,7 @@ class CroniterTest(unittest.TestCase):
     self.assertEqual(prev3.hour, 0)
     self.assertEqual(prev3.minute, 0)
 
-  def testPrevWeekDay(self):
+  def testPrevWeekDay2(self):
     base = datetime(2010, 8, 25, 15, 56)
     itr = croniter('10 0 * * 0', base)
     prev = itr.get_prev(datetime)
@@ -205,6 +225,31 @@ class CroniterTest(unittest.TestCase):
     self.assertEqual(n1.day, 22)
     self.assertEqual(n1.hour, 0)
     self.assertEqual(n1.minute, 5)
+
+  def testBug2(self):
+    base = datetime(2012, 01, 01, 00, 00)
+    iter = croniter('0 * * 3 *', base)
+    n1 = iter.get_next(datetime)
+    self.assertEqual(n1.year, base.year)
+    self.assertEqual(n1.month, 3)
+    self.assertEqual(n1.day, base.day)
+    self.assertEqual(n1.hour, base.hour)
+    self.assertEqual(n1.minute, base.minute)
+
+    n2 = iter.get_next(datetime)
+    self.assertEqual(n2.year, base.year)
+    self.assertEqual(n2.month, 3)
+    self.assertEqual(n2.day, base.day)
+    self.assertEqual(n2.hour, base.hour + 1)
+    self.assertEqual(n2.minute, base.minute)
+
+    n3 = iter.get_next(datetime)
+    self.assertEqual(n3.year, base.year)
+    self.assertEqual(n3.month, 3)
+    self.assertEqual(n3.day, base.day)
+    self.assertEqual(n3.hour, base.hour + 2)
+    self.assertEqual(n3.minute, base.minute)
+    
     
     
 if __name__ == '__main__':
